@@ -7,6 +7,8 @@ from pymunk.vec2d import vec2d
 import pygame
 import rabbyt
 
+from rabbyt.chipmunkglue import chipmunk_body_anims
+
 from math import cos, sin, radians, degrees
 import random
 import os.path
@@ -35,7 +37,7 @@ def create_cube(space, mass = 5.0, xy = (0,0)):
     shape.contents.collision_type = COLLTYPE_DEFAULT
     cp.cpSpaceAddShape(space, shape)
 
-    anims = rabbyt.physics.chipmunk_body_anims(ct.addressof(body[0]))
+    anims = chipmunk_body_anims(ct.addressof(body[0]))
     sprite.x, sprite.y, sprite.rot = anims
 
     return shape, sprite
