@@ -26,7 +26,7 @@ THE SOFTWARE.
 """)
 
 __author__ = "Matthew Marshall <matthew@matthewmarshall.org>"
-__version__ = "0.7"
+__version__ = "0.7.5b"
 
 import heapq
 import os.path
@@ -34,7 +34,8 @@ import os.path
 from rabbyt._rabbyt import *
 from rabbyt.sprites import *
 from rabbyt.anims import *
-import rabbyt.physics, rabbyt.collisions
+import rabbyt.collisions
+import rabbyt.dummy_physics as physics
 
 
 class Scheduler(object):
@@ -80,20 +81,27 @@ class Scheduler(object):
 scheduler = Scheduler()
 
 
-def init_display(size=(640, 480)):
+def init_display(size=(640, 480), flags = 0):
     """
-    init_display(size=(640, 480))
+    init_display(size=(640, 480), flags = 0)
 
     This is a small shortcut to create a pygame window, set the viewport, and
     set the opengl attributes need for rabbyt.
 
+    ``flags`` is passed to ``pygame.display.set_mode()`` (OR'ed with
+    ``pygame.OPENGL`` and ``pygame.DOUBLEBUF``.)
+
+    The pygame surface returned by ``pygame.display.set_mode()`` is returned.
+
     This function depends on pygame.
     """
     import pygame
     pygame.init()
-    pygame.display.set_mode(size, pygame.OPENGL | pygame.DOUBLEBUF)
+    surface = pygame.display.set_mode(size, pygame.OPENGL |
+            pygame.DOUBLEBUF | flags)
     set_viewport(size)
     set_default_attribs()
+    return surface
 
 _texture_cache = {}
 
@@ -120,12 +128,68 @@ def pygame_load_texture(filename, filter=True, mipmap=True):
         _texture_cache[filename] = load_texture(data, size, "RGBA",
                 filter, mipmap), size
     return _texture_cache[filename]
-set_load_texture_file_hook(pygame_load_texture)
 
-__all__ = __docs_all__ = ('anims collisions fonts sprites physics vertexarrays '
+def pyglet_load_texture(filename):
+    """
+    ``pyglet_load_texture(filename)``
+
+    Uses pyglet to load a texture from a file.  The texture is cached.
+
+    (This is meant to be used with ``set_load_texture_file_hook``.)
+    """
+    if filename not in _texture_cache:
+        from pyglet import image
+        if os.path.exists(filename):
+            img = image.load(filename)
+        else:
+            img = image.load(os.path.join(data_directory, filename))
+        _texture_cache[filename] = img.texture
+    return _texture_cache[filename]
+
+def autodetect_load_texture(filename):
+    """
+    ``autodetect_load_texture(filename)``
+
+    Automatically chooses between pyglet and pygame for loading a texture.
+
+    If pyglet is importable and pyglet.gl.get_current_context() does not
+    return None, pyglet will be used.  Otherwise, pygame is used.
+
+    After this function is called the first time, it automatically calls
+    ``set_load_texture_file_hook`` with the correct function, so there is
+    no additional overhead.
+
+    This is the default function for loading textures.
+    """
+    func = pygame_load_texture
+    try:
+        from pyglet.gl import get_current_context
+        if get_current_context():
+            # There is a pyglet context loaded; let's use pyglet's texture
+            # loading.
+            func = pyglet_load_texture
+        else:
+            # If there isn't a context, the user might be trying to load
+            # texture before creating the window.  If this is the case,
+            # we don't want to give a confusing ImportError if pygame is
+            # not installed.
+            try:
+                import pygame
+            except ImportError:
+                # Go ahead and use pyglet. It'll give a nice error.
+                func =  pyglet_load_texture
+    except ImportError:
+        pass
+
+    set_load_texture_file_hook(func)
+    return func(filename)
+set_load_texture_file_hook(autodetect_load_texture)
+
+__all__ = __docs_all__ = ('anims collisions fonts sprites vertexarrays '
 'Scheduler '
 'init_display set_viewport set_default_attribs set_gl_color clear '
 'get_gl_vendor '
 'render_unsorted '
-'load_texture update_texture unload_texture pygame_load_texture '
+'load_texture update_texture unload_texture '
+'autodetect_load_texture pyglet_load_texture pygame_load_texture '
 'set_load_texture_file_hook ').split()
\ No newline at end of file
